import { StateField, StateEffect } from '@codemirror/state';
const schemaEffect = StateEffect.define();
const schemaStateField = StateField.define({
    create() {
        return undefined;
    },
    update(schema, tr) {
        for (const e of tr.effects) {
            if (e.is(schemaEffect)) {
                return e.value;
            }
        }
        return schema;
    },
});
const optionsEffect = StateEffect.define();
const optionsStateField = StateField.define({
    create() {
        return undefined;
    },
    update(opts, tr) {
        for (const e of tr.effects) {
            if (e.is(optionsEffect)) {
                return e.value;
            }
        }
        return opts;
    },
});
export const updateSchema = (view, schema) => {
    view.dispatch({
        effects: schemaEffect.of(schema),
    });
};
export const updateOpts = (view, opts) => {
    view.dispatch({
        effects: optionsEffect.of(opts),
    });
};
export const getSchema = (state) => {
    return state.field(schemaStateField);
};
export const getOpts = (state) => {
    return state.field(optionsStateField);
};
export const stateExtensions = (schema, opts) => [schemaStateField.init(() => schema), optionsStateField.init(() => opts)];
//# sourceMappingURL=state.js.map